package com.ruoyi.bst.orderProd.domain;

import com.ruoyi.common.annotation.Excel;
import com.ruoyi.common.constant.DictType;
import com.ruoyi.common.core.domain.BaseEntity;
import com.ruoyi.common.core.validate.ValidGroup;
import com.ruoyi.system.valid.DictValid;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import javax.validation.constraints.Min;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;
import java.math.BigDecimal;

/**
 * 订单产品对象 bst_order_prod
 *
 * @author ruoyi
 * @date 2024-12-17
 */
@Data
public class OrderProd extends BaseEntity
{
    private static final long serialVersionUID = 1L;

    private Long id;

    @Excel(name = "订单ID")
    @ApiModelProperty("订单ID")
    private Long orderId;

    @Excel(name = "加工类型", readConverterExp = "1=自加工,2=外加工")
    @ApiModelProperty("加工类型")
    @DictValid(type = DictType.ORDER_PROD_WORK_TYPE, message = "非法的产品加工类型")
    @NotBlank(message = "产品加工类型不能为空", groups = {ValidGroup.Create.class})
    private String workType;

    @Excel(name = "是否成品")
    @ApiModelProperty("是否成品")
    @NotNull(message = "是否成品不能为空", groups = {ValidGroup.Create.class})
    private Boolean isEnd;

    @Excel(name = "物料编码")
    @ApiModelProperty("物料编码")
    @Size(max = 50, message = "物料编码长度不能超过50个字符")
    private String materialNo;

    @Excel(name = "主图")
    @ApiModelProperty("主图")
    private String picture;

    @Excel(name = "名称")
    @ApiModelProperty("名称")
    @Size(max = 50, message = "产品名称长度不能超过50个字符")
    @NotBlank(message = "产品名称不能为空", groups = {ValidGroup.Create.class})
    private String name;

    @Excel(name = "规格")
    @ApiModelProperty("规格")
    @Size(max = 50, message = "规格长度不能超过50个字符")
    private String spec;

    @Excel(name = "数量")
    @ApiModelProperty("数量")
    @Min(value = 1, message = "产品数量不能小于1")
    @NotNull(message = "产品数量不能为空", groups = {ValidGroup.Create.class})
    private BigDecimal num;

    @Excel(name = "排序")
    @ApiModelProperty("排序")
    private Integer sort;

    @Excel(name = "处理方式")
    @ApiModelProperty("处理方式")
    @Size(max = 50, message = "处理方式长度不能超过50个字符")
    private String handleWay;

    @Excel(name = "效果")
    @ApiModelProperty("效果")
    @Size(max = 50, message = "效果长度不能超过50个字符")
    private String effect;

    @Excel(name = "颜色")
    @ApiModelProperty("颜色")
    @Size(max = 50, message = "颜色长度不能超过50个字符")
    private String color;

    @Excel(name = "盖子颜色")
    @ApiModelProperty("盖子颜色")
    @Size(max = 50, message = "盖子颜色长度不能超过50个字符")
    private String coverColor;
}
