package com.ruoyi.bst.prodProcess.service.impl;

import com.ruoyi.bst.prodProcess.domain.ProdProcess;
import com.ruoyi.bst.prodProcess.domain.ProdProcessBO;
import com.ruoyi.bst.prodProcess.domain.ProdProcessVO;
import com.ruoyi.bst.prodProcess.service.ProdProcessAssembler;
import com.ruoyi.bst.store.domain.StoreQuery;
import com.ruoyi.bst.store.domain.enums.StoreGroupBy;
import com.ruoyi.bst.store.domain.enums.StoreStatus;
import com.ruoyi.bst.store.service.IStoreService;
import com.ruoyi.common.utils.collection.CollectionUtils;
import com.ruoyi.common.vo.LongDecimalVO;
import com.ruoyi.system.dept.domain.SysDeptQuery;
import com.ruoyi.system.dept.domain.SysDeptVO;
import com.ruoyi.system.dept.service.ISysDeptService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.util.List;
import java.util.Objects;

/**
 * @author wjh
 * 2024/12/20
 */
@Service
public class ProdProcessAssemblerImpl implements ProdProcessAssembler {
    @Autowired
    private ISysDeptService deptService;

    @Autowired
    private IStoreService storeService;

    @Override
    public void assembleDept(List<ProdProcessBO> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return;
        }

        SysDeptQuery query = new SysDeptQuery();
        query.setDeptIds(CollectionUtils.map(list, ProdProcess::getDeptId));
        List<SysDeptVO> deptList = deptService.selectDeptList(query);

        for (ProdProcessBO process : list) {
            SysDeptVO dept = deptList.stream().filter(item -> Objects.equals(item.getDeptId(), process.getDeptId())).findFirst().orElse(null);
            if (dept != null) {
                process.setDeptProcess(dept.getProcess());
            }
        }

    }

    @Override
    public void assembleReportNum(List<ProdProcessVO> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return ;
        }

        StoreQuery query = new StoreQuery();
        query.setProcessIds(CollectionUtils.map(list, ProdProcessVO::getId));
        List<LongDecimalVO> groups = storeService.selectSumOfNumGroupByLong(query, StoreGroupBy.PROCESS_ID);

        for (ProdProcessVO process : list) {
            LongDecimalVO vo = groups.stream().filter(item -> Objects.equals(item.getKey(), process.getId())).findFirst().orElse(null);
            if (vo == null) {
                process.setReportNum(BigDecimal.ZERO);
            } else {
                process.setReportNum(vo.getValue());
            }
        }
    }

    @Override
    public void assembleStoreNum(List<ProdProcessVO> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return ;
        }

        StoreQuery query = new StoreQuery();
        query.setProcessIds(CollectionUtils.map(list, ProdProcessVO::getId));
        query.setStatus(StoreStatus.STORED.getStatus());
        List<LongDecimalVO> groups = storeService.selectSumOfStoreNumGroupByLong(query, StoreGroupBy.PROCESS_ID);

        for (ProdProcessVO process : list) {
            LongDecimalVO vo = groups.stream().filter(item -> Objects.equals(item.getKey(), process.getId())).findFirst().orElse(null);
            if (vo == null) {
                process.setStoreNum(BigDecimal.ZERO);
            } else {
                process.setStoreNum(vo.getValue());
            }
        }
    }

    @Override
    public void assembleProgress(List<ProdProcessVO> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return;
        }
        this.assembleReportNum(list);
        this.assembleStoreNum(list);
    }
}
