package com.ruoyi.web.bst;

import com.ruoyi.bst.prodProcess.domain.ProdProcess;
import com.ruoyi.bst.prodProcess.domain.ProdProcessQuery;
import com.ruoyi.bst.prodProcess.domain.ProdProcessVO;
import com.ruoyi.bst.prodProcess.service.IProdProcessService;
import com.ruoyi.bst.prodProcess.service.ProdProcessAssembler;
import com.ruoyi.common.annotation.DataScope;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 产品工序Controller
 *
 * @author ruoyi
 * @date 2024-12-17
 */
@RestController
@RequestMapping("/bst/prodProcess")
public class ProdProcessController extends BaseController
{
    @Autowired
    private IProdProcessService prodProcessService;

    @Autowired
    private ProdProcessAssembler prodProcessAssembler;

    /**
     * 查询产品工序列表
     */
    @PreAuthorize("@ss.hasPermi('bst:prodProcess:list')")
    @GetMapping("/list")
    @DataScope(deptAlias = "sd")
    public TableDataInfo list(ProdProcessQuery query)
    {
        startPage();
        startOrderBy();
        List<ProdProcessVO> list = prodProcessService.selectProdProcessList(query);
        prodProcessAssembler.assembleProgress(list);
        return getDataTable(list);
    }

    /**
     * 查询产品工序列表
     */
    @PreAuthorize("@ss.hasPermi('bst:prodProcess:list')")
    @PostMapping("/listByIds")
    public AjaxResult listByIds(@RequestBody List<Long> ids)
    {
        List<ProdProcessVO> list = prodProcessService.selectByIds(ids);
        return success(list);
    }

    /**
     * 导出产品工序列表
     */
    @PreAuthorize("@ss.hasPermi('bst:prodProcess:export')")
    @Log(title = "产品工序", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ProdProcessQuery query)
    {
        List<ProdProcessVO> list = prodProcessService.selectProdProcessList(query);
        ExcelUtil<ProdProcessVO> util = new ExcelUtil<ProdProcessVO>(ProdProcessVO.class);
        util.exportExcel(response, list, "产品工序数据");
    }

    /**
     * 获取产品工序详细信息
     */
    @PreAuthorize("@ss.hasPermi('bst:prodProcess:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(prodProcessService.selectProdProcessById(id));
    }

    /**
     * 新增产品工序
     */
    @PreAuthorize("@ss.hasPermi('bst:prodProcess:add')")
    @Log(title = "产品工序", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ProdProcess prodProcess)
    {
        return toAjax(prodProcessService.insertProdProcess(prodProcess));
    }

    /**
     * 修改产品工序
     */
    @PreAuthorize("@ss.hasPermi('bst:prodProcess:edit')")
    @Log(title = "产品工序", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ProdProcess prodProcess)
    {
        return toAjax(prodProcessService.updateProdProcess(prodProcess));
    }

    /**
     * 删除产品工序
     */
    @PreAuthorize("@ss.hasPermi('bst:prodProcess:remove')")
    @Log(title = "产品工序", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(prodProcessService.deleteProdProcessByIds(ids));
    }
}
